@@ -138,9 +138,13 @@ static GOptionEntry main_entries[] = {
 	{ "window", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, option_parse,
           N_("X window ID of the window to examine or modify"), N_("XID") },
 	{ "application", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, option_parse,
+        /* Translators: A group leader is the window that is the "owner" of a group
+         * of windows, ie: if you have multiple windows in one application, one window
+         * has some information about the application (like the application name). */
           N_("X window ID of the group leader of an application to examine"),
           N_("XID") },
 	{ "class", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, option_parse,
+        /* Translators: A class is like a "family". E.g., all gvim windows are of the same class. */
           N_("Class resource of the class group to examine"), N_("CLASS") },
 	{ "workspace", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, option_parse,
           N_("NUMBER of the workspace to examine or modify"), N_("NUMBER") },
@@ -153,6 +157,7 @@ static GOptionEntry main_entries[] = {
 
 static GOptionEntry list_entries[] = {
 	{ "list", 0, 0, G_OPTION_ARG_NONE, &list,
+        /* Translators: A class is like a "family". E.g., all gvim windows are of the same class. */
           N_("List windows of the application/class group/workspace/screen (output format: \"XID: Window Name\")"), NULL },
 	{ "list-workspaces", 0, 0, G_OPTION_ARG_NONE, &list_workspaces,
           N_("List workspaces of the screen (output format: \"Number: Workspace Name\")"), NULL },
@@ -171,8 +176,12 @@ static GOptionEntry screen_entries[] = {
 	{ "unshow-desktop", 0, 0, G_OPTION_ARG_NONE, &set_unshow_desktop,
           N_("Stop showing the desktop"), NULL },
 	{ "move-viewport-x", 0, 0, G_OPTION_ARG_INT, &set_viewport_x,
+        /* Translators: 'viewport' is kind of the viewable area. a viewport can be used to implement
+        a workspace (e.g. compiz is an example); however it is not just the current workspace. */
           N_("Move the viewport of the current workspace to X coordinate X"), N_("X") },
 	{ "move-viewport-y", 0, 0, G_OPTION_ARG_INT, &set_viewport_y,
+        /* Translators: 'viewport' is kind of the viewable area. a viewport can be used to implement
+        a workspace (e.g. compiz is an example); however it is not just the current workspace. */
           N_("Move the viewport of the current workspace to Y coordinate Y"), N_("Y") },
 	{ NULL }
 };
@@ -220,16 +229,30 @@ static GOptionEntry window_entries[] = {
 	{ "unshade", 0, 0, G_OPTION_ARG_NONE, &set_unshade,
           N_("Unshade the window"), NULL },
 	{ "stick", 0, 0, G_OPTION_ARG_NONE, &set_stick,
+        /* Translators: 'viewport' is kind of the viewable area. a viewport can be used to implement
+        a workspace (e.g. compiz is an example); however it is not just the current workspace. */
           N_("Make the window have a fixed position in the viewport"), NULL },
 	{ "unstick", 0, 0, G_OPTION_ARG_NONE, &set_unstick,
+        /* Translators: 'viewport' is kind of the viewable area. a viewport can be used to implement
+        a workspace (e.g. compiz is an example); however it is not just the current workspace. */
           N_("Make the window not have a fixed position in the viewport"), NULL },
 	{ "skip-pager", 0, 0, G_OPTION_ARG_NONE, &set_skip_pager,
+  /* Translators: A pager is the technical term for the workspace switcher.
+   * It's a representation of all workspaces with windows inside it.
+   * Please make sure that the translation is in sync with gnome-panel,
+   * where this term is also used in translatable strings */
           N_("Make the window not appear in pagers"), NULL },
 	{ "unskip-pager", 0, 0, G_OPTION_ARG_NONE, &set_unskip_pager,
+  /* Translators: A pager is the technical term for the workspace switcher.
+   * It's a representation of all workspaces with windows inside it.
+   * Please make sure that the translation is in sync with gnome-panel,
+   * where this term is also used in translatable strings */
           N_("Make the window appear in pagers"), NULL },
 	{ "skip-tasklist", 0, 0, G_OPTION_ARG_NONE, &set_skip_tasklist,
+  /* Translators: "tasklist" is the list of running applications (the window list) */
           N_("Make the window not appear in tasklists"), NULL },
 	{ "unskip-tasklist", 0, 0, G_OPTION_ARG_NONE, &set_unskip_tasklist,
+  /* Translators: "tasklist" is the list of running applications (the window list) */
           N_("Make the window appear in tasklists"), NULL },
 	{ "pin", 0, 0, G_OPTION_ARG_NONE, &set_pin,
           N_("Make the window visible on all workspaces"), NULL },
@@ -550,6 +573,7 @@ set_mode (int         new_mode,
           mode = CLASS_GROUP_LIST_MODE;
         else if (new_mode != CLASS_GROUP_READ_MODE)
           {
+        /* Translators: A class is like a "family". E.g., all gvim windows are of the same class. */
             g_printerr (_("Conflicting options are present: class group "
                           "\"%s\" should be interacted with, but --%s has "
                           "been used\n"),
@@ -560,6 +584,7 @@ set_mode (int         new_mode,
       case CLASS_GROUP_LIST_MODE:
         if (new_mode != CLASS_GROUP_LIST_MODE)
           {
+        /* Translators: A class is like a "family". E.g., all gvim windows are of the same class. */
             g_printerr (_("Conflicting options are present: windows of class "
                           "group \"%s\" should be listed, but --%s has "
                           "been used\n"),
@@ -854,10 +879,14 @@ update_screen (WnckScreen *screen)
                wnck_screen_move_viewport (screen, viewport_x, viewport_y);
              }
            else
+        /* Translators: 'viewport' is kind of the viewable area. a viewport can be used to implement
+        a workspace (e.g. compiz is an example); however it is not just the current workspace. */
          g_printerr (_("Viewport cannot be moved: "
                        "the current workspace does not contain a viewport\n"));
          }
        else
+        /* Translators: 'viewport' is kind of the viewable area. a viewport can be used to implement
+        a workspace (e.g. compiz is an example); however it is not just the current workspace. */
          g_printerr (_("Viewport cannot be moved: "
                        "there is no current workspace\n"));
     }
@@ -1053,6 +1082,7 @@ list_windows (GList *windows)
       if (wnck_window_has_name (window))
         buf = wnck_window_get_name (window);
       else
+        /* Translators: 'unset' in the sense of "something has not been set". */
         buf = _("<name unset>");
 
       /* Translators: %lu is a window number and %s a window name */
@@ -1183,6 +1213,7 @@ print_screen (WnckScreen *screen)
       if (wnck_window_has_name (window))
         name = g_strdup_printf (_("\"%s\""), wnck_window_get_name (window));
       else
+      /* Translators: 'unset' in the sense of "something has not been set". */
         name = g_strdup (_("<name unset>"));
 
       /* Translators: %lu is a window number and %s a window name */
@@ -1228,7 +1259,11 @@ print_workspace (WnckWorkspace *space)
                                 wnck_workspace_get_viewport_x (space),
                                 wnck_workspace_get_viewport_y (space));
   else
+        /* Translators: 'viewport' is kind of the viewable area. a viewport can be used to implement
+        a workspace (e.g. compiz is an example); however it is not just the current workspace. */
     free_buf = g_strdup (_("<no viewport>"));
+        /* Translators: 'viewport' is kind of the viewable area. a viewport can be used to implement
+        a workspace (e.g. compiz is an example); however it is not just the current workspace. */
   g_print (_("Viewport position (x, y): %s\n"), free_buf);
   g_free (free_buf);
 
@@ -1288,6 +1323,7 @@ print_class_group (WnckClassGroup *class_group)
 
   windows = wnck_class_group_get_windows (class_group);
 
+  /* Translators: Ressource class is the name to identify a class. */
   g_print (_("Resource Class: %s\n"),
            wnck_class_group_get_res_class (class_group));
   g_print (_("Group Name: %s\n"), wnck_class_group_get_name (class_group));
@@ -1295,8 +1331,10 @@ print_class_group (WnckClassGroup *class_group)
   /* TODO: missing API */
 #if 0
   if (!wnck_class_group_get_icon_is_fallback (class_group))
+    /* Translators: 'set' in the sense of "something has been set". */
     buf = _("set");
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     buf = _("<unset>");
   g_print (_("Icons: %s\n"), buf);
 #endif
@@ -1317,14 +1355,17 @@ print_application (WnckApplication *app)
   g_print (_("Icon Name: %s\n"), wnck_application_get_icon_name (app));
 
   if (!wnck_application_get_icon_is_fallback (app))
+    /* Translators: 'set' in the sense of "something has been set". */
     buf = _("set");
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     buf = _("<unset>");
   g_print (_("Icons: %s\n"), buf);
 
   if (wnck_application_get_pid (app) != 0)
     free_buf = g_strdup_printf ("%d", wnck_application_get_pid (app));
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     free_buf = g_strdup (_("<unset>"));
   g_print (_("PID: %s\n"), free_buf);
   g_free (free_buf);
@@ -1353,20 +1394,24 @@ print_window (WnckWindow *window)
   if (wnck_window_has_name (window))
     buf = wnck_window_get_name (window);
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     buf = _("<unset>");
   g_print (_("Name: %s\n"), buf);
 
   if (wnck_window_has_icon_name (window))
     buf = wnck_window_get_icon_name (window);
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     buf = _("<unset>");
   /* Translators: note that "Icon" here has a specific window
    * management-related meaning. It means minimized. */
   g_print (_("Icon Name: %s\n"), buf);
 
   if (!wnck_window_get_icon_is_fallback (window))
+    /* Translators: 'set' in the sense of "something has been set". */
     buf = _("set");
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     buf = _("<unset>");
   g_print (_("Icons: %s\n"), buf);
 
@@ -1430,7 +1475,9 @@ print_window (WnckWindow *window)
   if (strcmp (wnck_class_group_get_res_class (class_group), ""))
     buf = wnck_class_group_get_res_class (class_group);
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     buf = _("<unset>");
+        /* Translators: A class is like a "family". E.g., all gvim windows are of the same class. */
   g_print (_("Class Group: %s\n"), buf);
 
   g_print (_("XID: %lu\n"), wnck_window_get_xid (window));
@@ -1438,6 +1485,7 @@ print_window (WnckWindow *window)
   if (wnck_window_get_pid (window) != 0)
     free_buf = g_strdup_printf ("%d", wnck_window_get_pid (window));
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     free_buf = g_strdup (_("<unset>"));
   g_print (_("PID: %s\n"), free_buf);
   g_free (free_buf);
@@ -1445,14 +1493,19 @@ print_window (WnckWindow *window)
   if (wnck_window_get_session_id (window))
     buf = wnck_window_get_session_id (window);
   else
+    /* Translators: 'unset' in the sense of "something has not been set". */
     buf = _("<unset>");
   g_print (_("Session ID: %s\n"), buf);
 
   if (wnck_window_get_group_leader (window) != wnck_window_get_xid (window))
+        /* Translators: A group leader is the window that is the "owner" of a group
+         * of windows, ie: if you have multiple windows in one application, one window
+         * has some information about the application (like the application name). */
     g_print (_("Group Leader: %lu\n"), wnck_window_get_group_leader (window));
   //FIXME: else print something?
 
   if (wnck_window_get_transient (window))
+  /* Translators: A window can be transient for another window: it means it's on top of it */
     g_print (_("Transient for: %lu\n"),
              wnck_window_get_xid (wnck_window_get_transient (window)));
   //FIXME: else print something?
@@ -1463,11 +1516,15 @@ print_window (WnckWindow *window)
       char *tmp;                                                \
                                                                 \
       /* Translators: we're building a list of items here.      \
-       * The end result is something like "a, b, c"             \
-       * In this case, the first string is "a, b", the second   \
-       * string is ", " and the third string is "c" */          \
+       * For example, the result is "a, b".                     \
+       * In this case, the first string is "a", the second      \
+       * string is ", " and the third string is "b".            \
+       * We can then use this information here to also          \
+       * recursively build longer lists, like "a, b, c, d" */   \
       tmp = g_strdup_printf (_("%1$s%2$s%3$s"),                 \
                              free_buf ? free_buf : "",          \
+      /* Translators: see comment for "%1$s%2$s%3$s" in order   \
+       * to properly translate this */                          \
                              free_buf ? _(", ") : "",           \
                              string);                           \
       g_free (free_buf);                                        \
@@ -1490,7 +1547,12 @@ print_window (WnckWindow *window)
   PRINT_LIST_ITEM (wnck_window_is_below, _("below"));
   PRINT_LIST_ITEM (wnck_window_is_fullscreen, _("fullscreen"));
   PRINT_LIST_ITEM (wnck_window_needs_attention, _("needs attention"));
+  /* Translators: A pager is the technical term for the workspace switcher.
+   * It's a representation of all workspaces with windows inside it.
+   * Please make sure that the translation is in sync with gnome-panel,
+   * where this term is also used in translatable strings */
   PRINT_LIST_ITEM (wnck_window_is_skip_pager, _("skip pager"));
+  /* Translators: "tasklist" is the list of running applications (the window list) */
   PRINT_LIST_ITEM (wnck_window_is_skip_tasklist, _("skip tasklist"));
   if (!free_buf)
     free_buf = g_strdup (_("normal"));
@@ -1873,6 +1935,7 @@ main (int argc, char **argv)
             g_assert_not_reached ();
         }
       else
+        /* Translators: A class is like a "family". E.g., all gvim windows are of the same class. */
         g_printerr (_("Cannot interact with class group \"%s\": "
                       "the class group cannot be found\n"),
                     interact_class_group);
